.. _all-salt.pillars:

===================================
Full list of builtin pillar modules
===================================

.. currentmodule:: salt.pillar

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cmd_json
    cmd_yaml
    cobbler
    django_orm
    git_pillar
    hiera
    libvirt
    mongo
    pillar_ldap
    puppet
    reclass_adapter
    virtkey
